"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var themes_1 = require("./themes");
var resolver_1 = require("./resolver");
var onigLibs_1 = require("./onigLibs");
var tokenizer_1 = require("./tokenizer");
var DATA_PATH = path.resolve(__dirname, '../data');
var THEMES = [
    new themes_1.ThemeInfo('abyss', 'Abyss.tmTheme'),
    new themes_1.ThemeInfo('dark_vs', 'dark_vs.json'),
    new themes_1.ThemeInfo('light_vs', 'light_vs.json'),
    new themes_1.ThemeInfo('hc_black', 'hc_black.json'),
    new themes_1.ThemeInfo('dark_plus', 'dark_plus.json', 'dark_vs.json'),
    new themes_1.ThemeInfo('light_plus', 'light_plus.json', 'light_vs.json'),
    new themes_1.ThemeInfo('kimbie_dark', 'Kimbie_dark.tmTheme'),
    new themes_1.ThemeInfo('monokai', 'Monokai.tmTheme'),
    new themes_1.ThemeInfo('monokai_dimmed', 'dimmed-monokai.tmTheme'),
    new themes_1.ThemeInfo('quietlight', 'QuietLight.tmTheme'),
    new themes_1.ThemeInfo('red', 'red.tmTheme'),
    new themes_1.ThemeInfo('solarized_dark', 'Solarized-dark.tmTheme'),
    new themes_1.ThemeInfo('solarized_light', 'Solarized-light.tmTheme'),
    new themes_1.ThemeInfo('tomorrow_night_blue', 'Tomorrow-Night-Blue.tmTheme')
];
var LANGUAGES = [
    'javascript',
    'typescript',
    'html',
    'xml',
    'json',
    'css',
    'scss',
    'java',
    'python',
    'markdown',
    'shellscript',
    'dockerfile',
    'bat',
    'ini'
];
var _grammars = JSON.parse(fs.readFileSync(path.resolve(DATA_PATH, 'grammars.json')).toString('utf8'));
for (var _i = 0, _grammars_1 = _grammars; _i < _grammars_1.length; _i++) {
    var grammar = _grammars_1[_i];
    grammar.path = path.join(DATA_PATH, grammar.path);
}
var _languages = JSON.parse(fs.readFileSync(path.join(DATA_PATH, 'languages.json')).toString('utf8'));
var OnigasmResolver = new resolver_1.Resolver(_grammars, _languages, onigLibs_1.getOnigasm(), 'onigasm');
var _themeDatas = THEMES.map(function (theme) { return theme.create(OnigasmResolver); });
function getCodeTokenizer(themeName) {
    return __awaiter(this, void 0, void 0, function () {
        var themeData, tokenizerMap, _loop_1, _i, LANGUAGES_1, lang, grammarLoadingPromises;
        var _this = this;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    themeData = _themeDatas.find(function (td) { return td.themeName === themeName; });
                    tokenizerMap = {};
                    _loop_1 = function (lang) {
                        var grammar = _grammars.find(function (g) { return g.language === lang; });
                        var langDefinition = _languages.find(function (l) { return l.id === lang; });
                        var embeddedLanguages = Object.create(null);
                        if (grammar.embeddedLanguages) {
                            for (var scopeName in grammar.embeddedLanguages) {
                                embeddedLanguages[scopeName] = OnigasmResolver.language2id[grammar.embeddedLanguages[scopeName]];
                            }
                        }
                        if (!tokenizerMap[lang]) {
                            tokenizerMap[lang] = {
                                tokenizer: new tokenizer_1.ThemeTokenizer(themeData, grammar.scopeName, OnigasmResolver.language2id[lang], embeddedLanguages),
                                grammar: null
                            };
                            if (langDefinition.aliases) {
                                langDefinition.aliases.forEach(function (a) {
                                    tokenizerMap[a] = tokenizerMap[lang];
                                });
                            }
                        }
                    };
                    for (_i = 0, LANGUAGES_1 = LANGUAGES; _i < LANGUAGES_1.length; _i++) {
                        lang = LANGUAGES_1[_i];
                        _loop_1(lang);
                    }
                    grammarLoadingPromises = Object.keys(tokenizerMap).map(function (lang) { return __awaiter(_this, void 0, void 0, function () {
                        var _a;
                        return __generator(this, function (_b) {
                            switch (_b.label) {
                                case 0:
                                    _a = tokenizerMap[lang];
                                    return [4 /*yield*/, tokenizerMap[lang].tokenizer.loadGrammarAsync()];
                                case 1:
                                    _a.grammar = _b.sent();
                                    return [2 /*return*/];
                            }
                        });
                    }); });
                    return [4 /*yield*/, Promise.all(grammarLoadingPromises)];
                case 1:
                    _a.sent();
                    return [2 /*return*/, function (code, lang) {
                            return tokenizerMap[lang].tokenizer.tokenizeWithTheme(code, tokenizerMap[lang].grammar);
                        }];
            }
        });
    });
}
exports.getCodeTokenizer = getCodeTokenizer;
function buildHTML(lines, langId) {
    var html = '';
    html += "<pre class=\"shiki\"><div class=\"language-id\">" + langId + "</div><code>";
    lines.forEach(function (l) {
        if (l.length === 0) {
            html += "\n";
        }
        else {
            l.forEach(function (token) {
                html += "<span style=\"color: " + token.color + "\">" + escapeHtml(token.content) + "</span>";
            });
            html += "\n";
        }
    });
    html += "</code></pre>";
    return html;
}
exports.buildHTML = buildHTML;
function escapeHtml(html) {
    return html.replace(/</g, '&lt;').replace(/>/g, '&gt;');
}
//# sourceMappingURL=main.js.map