/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var themedTokenizer_1 = require("./themedTokenizer");
var SingleThemeTest = /** @class */ (function () {
    function SingleThemeTest(themeName, testName, contents, initialScopeName, initialLanguage, embeddedLanguages) {
        this.themeName = themeName;
        this.testName = testName;
        this.contents = contents;
        this.initialScopeName = initialScopeName;
        this.initialLanguage = initialLanguage;
        this.embeddedLanguages = embeddedLanguages;
        this.backgroundColor = null;
        this.actual = null;
        this.diff = null;
        this.patchedDiff = null;
    }
    SingleThemeTest.prototype.evaluate = function (themeData) {
        this.backgroundColor = themeData.theme.settings[0].settings.background;
        return this._tokenizeWithThemeAsync(themeData);
    };
    SingleThemeTest.prototype._tokenizeWithThemeAsync = function (themeData) {
        var _this = this;
        return themeData.registry.loadGrammarWithEmbeddedLanguages(this.initialScopeName, this.initialLanguage, this.embeddedLanguages).then(function (grammar) {
            return themedTokenizer_1.tokenizeWithTheme(themeData.theme, themeData.registry.getColorMap(), _this.contents, grammar);
        });
    };
    SingleThemeTest.computeThemeTokenizationDiff = function (_actual, _expected) {
        var canonicalTokens = [];
        for (var i = 0, len = _actual.length; i < len; i++) {
            var explanation = _actual[i].explanation;
            for (var j = 0, lenJ = explanation.length; j < lenJ; j++) {
                canonicalTokens.push(explanation[j].content);
            }
        }
        var actual = [];
        for (var i = 0, len = _actual.length; i < len; i++) {
            var item = _actual[i];
            for (var j = 0, lenJ = item.explanation.length; j < lenJ; j++) {
                actual.push({
                    content: item.explanation[j].content,
                    color: item.color,
                    scopes: item.explanation[j].scopes
                });
            }
        }
        var expected = [];
        for (var i = 0, len = _expected.length, canonicalIndex = 0; i < len; i++) {
            var item = _expected[i];
            var content = item.content;
            while (content.length > 0) {
                expected.push({
                    oldIndex: i,
                    content: canonicalTokens[canonicalIndex],
                    color: item.color,
                    _t: item._t,
                    _r: item._r
                });
                content = content.substr(canonicalTokens[canonicalIndex].length);
                canonicalIndex++;
            }
        }
        if (actual.length !== expected.length) {
            throw new Error('Content mismatch');
        }
        var diffs = [];
        for (var i = 0, len = actual.length; i < len; i++) {
            var expectedItem = expected[i];
            var actualItem = actual[i];
            var contentIsInvisible = /^\s+$/.test(expectedItem.content);
            if (contentIsInvisible) {
                continue;
            }
            if (actualItem.color.substr(0, 7) !== expectedItem.color) {
                diffs.push({
                    oldIndex: expectedItem.oldIndex,
                    oldToken: expectedItem,
                    newToken: actualItem
                });
            }
        }
        return diffs;
    };
    return SingleThemeTest;
}());
exports.SingleThemeTest = SingleThemeTest;
//# sourceMappingURL=themeTest.js.map