"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var vscode_textmate_1 = require("vscode-textmate");
var plist = require("./plist");
var THEMES_TEST_PATH = path.resolve(__dirname, '../data/themes');
var ThemeInfo = /** @class */ (function () {
    function ThemeInfo(themeName, filename, includeFilename) {
        this._themeName = themeName;
        this._filename = filename;
        this._includeFilename = includeFilename;
    }
    ThemeInfo._loadThemeFile = function (filename) {
        var fullPath = path.join(THEMES_TEST_PATH, filename);
        var fileContents = fs.readFileSync(fullPath).toString();
        if (/\.json$/.test(filename)) {
            return JSON.parse(fileContents);
        }
        return plist.parse(fileContents);
    };
    ThemeInfo.prototype.create = function (resolver) {
        var theme = ThemeInfo._loadThemeFile(this._filename);
        if (this._includeFilename) {
            var includeTheme = ThemeInfo._loadThemeFile(this._includeFilename);
            theme.settings = includeTheme.settings.concat(theme.settings);
        }
        // console.log(JSON.stringify(theme, null, '\t')); process.exit(0);
        var registry = new vscode_textmate_1.Registry(resolver);
        registry.setTheme(theme);
        return {
            themeName: this._themeName,
            theme: theme,
            registry: registry
        };
    };
    return ThemeInfo;
}());
exports.ThemeInfo = ThemeInfo;
//# sourceMappingURL=themes.js.map